package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.DSAParameter;
import cn.com.infosec.asn1.x509.SubjectPublicKeyInfo;
import cn.com.infosec.asn1.x9.X9ObjectIdentifiers;
import cn.com.infosec.crypto.params.DSAPublicKeyParameters;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.math.BigInteger;
import java.security.interfaces.DSAParams;
import java.security.interfaces.DSAPublicKey;
import java.security.spec.DSAParameterSpec;
import java.security.spec.DSAPublicKeySpec;

public class JDKDSAPublicKey implements DSAPublicKey {
   private static final long serialVersionUID = 1752452449903495175L;
   private BigInteger y;
   private DSAParams dsaSpec;

   JDKDSAPublicKey(DSAPublicKeySpec spec) {
      JDKDSAPublicKey var10000 = this;
      super();
      this.y = spec.getY();
      DSAPublicKeySpec var10003 = spec;
      BigInteger var3 = spec.getP();
      BigInteger spec1 = spec.getQ();
      BigInteger var2 = var10003.getG();
      var10000.dsaSpec = new DSAParameterSpec(var3, spec1, var2);
   }

   JDKDSAPublicKey(DSAPublicKey key) {
      this.y = key.getY();
      this.dsaSpec = key.getParams();
   }

   JDKDSAPublicKey(DSAPublicKeyParameters params) {
      JDKDSAPublicKey var10000 = this;
      super();
      this.y = params.getY();
      BigInteger var10003 = params.getParameters().getP();
      BigInteger var2 = params.getParameters().getQ();
      var10000.dsaSpec = new DSAParameterSpec(var10003, var2, params.getParameters().getG());
   }

   JDKDSAPublicKey(BigInteger y, DSAParameterSpec dsaSpec) {
      this.y = y;
      this.dsaSpec = dsaSpec;
   }

   JDKDSAPublicKey(SubjectPublicKeyInfo info) {
      SubjectPublicKeyInfo var10003 = info;
      super();

      DERInteger var7;
      try {
         var7 = (DERInteger)var10003.getPublicKey();
      } catch (IOException var3) {
         throw new IllegalArgumentException("invalid info structure in DSA public key");
      }

      this.y = var7.getValue();
      if (this.isNotNull(info.getAlgorithmId().getParameters())) {
         JDKDSAPublicKey var10000 = this;
         DSAParameter var4;
         var4 = new DSAParameter.<init>((ASN1Sequence)info.getAlgorithmId().getParameters());
         DSAParameter var8 = var4;
         DSAParameter var10004 = var4;
         BigInteger var5 = var4.getP();
         BigInteger info1 = var10004.getQ();
         BigInteger var2 = var8.getG();
         var10000.dsaSpec = new DSAParameterSpec(var5, info1, var2);
      }

   }

   private boolean isNotNull(DEREncodable parameters) {
      return parameters != null && !DERNull.INSTANCE.equals(parameters);
   }

   private void readObject(ObjectInputStream in) {
      this.y = (BigInteger)in.readObject();
      BigInteger var2;
      this.dsaSpec = new DSAParameterSpec(var2 = (BigInteger)in.readObject(), var2, (BigInteger)in.readObject());
   }

   private void writeObject(ObjectOutputStream out) {
      out.writeObject(this.y);
      out.writeObject(this.dsaSpec.getP());
      out.writeObject(this.dsaSpec.getQ());
      out.writeObject(this.dsaSpec.getG());
   }

   public String getAlgorithm() {
      return "DSA";
   }

   public String getFormat() {
      return "X.509";
   }

   public byte[] getEncoded() {
      DSAParams var1;
      if ((var1 = this.dsaSpec) == null) {
         AlgorithmIdentifier var10002 = new AlgorithmIdentifier(X9ObjectIdentifiers.id_dsa);
         DERInteger var3;
         var3 = new DERInteger.<init>(this.y);
         return (new SubjectPublicKeyInfo(var10002, var3)).getDEREncoded();
      } else {
         DERObjectIdentifier var10004 = X9ObjectIdentifiers.id_dsa;
         BigInteger var10007 = var1.getP();
         BigInteger var2 = this.dsaSpec.getQ();
         return (new SubjectPublicKeyInfo(new AlgorithmIdentifier(var10004, (new DSAParameter(var10007, var2, this.dsaSpec.getG())).getDERObject()), new DERInteger(this.y))).getDEREncoded();
      }
   }

   public DSAParams getParams() {
      return this.dsaSpec;
   }

   public BigInteger getY() {
      return this.y;
   }

   public String toString() {
      StringBuffer var10000 = new StringBuffer();
      String var1 = System.getProperty("line.separator");
      var10000.append("DSA Public Key").append(var1);
      var10000.append("            y: ").append(this.getY().toString(16)).append(var1);
      return var10000.toString();
   }

   public int hashCode() {
      return this.getY().hashCode() ^ this.getParams().getG().hashCode() ^ this.getParams().getP().hashCode() ^ this.getParams().getQ().hashCode();
   }

   public boolean equals(Object o) {
      if (!(o instanceof DSAPublicKey)) {
         return false;
      } else {
         DSAPublicKey o1 = (DSAPublicKey)o;
         return this.getY().equals(o1.getY()) && this.getParams().getG().equals(o1.getParams().getG()) && this.getParams().getP().equals(o1.getParams().getP()) && this.getParams().getQ().equals(o1.getParams().getQ());
      }
   }
}
